<div class="paginate">
    <a {% if object_list.has_previous %}href="?page=1"{% endif %}>⇐</a>
    <a {% if object_list.has_previous %}href="?page={{ object_list.previous_page_number }}"{% endif %}>←</a>
        
    <span style="cursor:default">ω</span>

    <a {% if object_list.has_next %}href="?page={{ object_list.next_page_number }}"{% endif %}>→</a>
    <a {% if object_list.has_next %}href="?page={{ object_list.paginator.num_pages }}"{% endif %}>⇒</a>
</div>
