{% extends "forum/profile.html" %}
{% load i18n %}
{% block profile_content %}
<div class="edit_profile">
    <form method="post" enctype="multipart/form-data">{% csrf_token %}
        {% include "forum/form.html" %}
        <input class="button tiny" type="submit" value='{% trans "Save" %}' />
    </form>
</div>
{% endblock %}