/*  More Framework
    https://bitbucket.org/italomaia/more-framework
    by Italo Maia

    License: http://creativecommons.org/licenses/MIT/

    Coding style:
    * http://drupal.org/node/302199
    * http://www.phpied.com/css-coding-conventions/

    See also:
    * http://lessframework.com/
    * http://css-tricks.com/
    * http://cssglobe.com/

* */

table{ border-spacing: 0px; width: 100%; margin-bottom: 1em; }
table td, table th { text-align:center; }
table td:first-child, table th:first-child{ text-align: left; padding-left: 4px; }
table tr.even{ background-color: #fff8cf; }

nav { padding: 0px .4em; }
nav > ul { margin-bottom: 0px; }
nav > a+a { margin-left: 4px; }

a { cursor: default; }
a img { border: 0px; }
a[href] { cursor: pointer; }

figure { position: relative; }
figure img { width: 100%; }

ul, ol, dl { margin-bottom: 10px; }
li, dd { margin-left: 24px; }
dt { font-weight: bold; }
li *, ol *, dl * { vertical-align: middle; }

form > ul, nav > ul { list-style: none; }
form > ul > li, nav > ul > li { margin-left: 0px; }


/*  Typography presets
    ------------------  */

h1, h2, h3, h4, h5, h6, .gigantic { display: block }

.gigantic {
    font-size: 80px;
    line-height: 90px;
    letter-spacing: -2px;
}

.huge, h1 {
    font-size: 48px;
    line-height: 52px;
    letter-spacing: -1px;
}

.large, h2 {
    font-size: 38px;
    line-height: 44px;
}

.bigger, h3 {
    font-size: 26px;
    line-height: 36px;
}

.big, h4 {
    font-size: 22px;
    line-height: 30px;
}

p {
    text-align: justify;
    padding: 2px 4px;
}
p, pre {
    margin-bottom: 1em;
}
progress {
    -webkit-appearance: progress-bar;
    border: 1px solid #D3D3D3;
    background-color: white;
}

label {
    font-weight: bold;
    padding-left: 2px;
    padding-right: 2px;
    display: inline-block;
    text-align: center;
}

strong, b { color: #b03060; }
em, i { color: #a020f0; }

del, ins { font-weight: bold; }
del { color: #ff4500; }
ins { color: #4169e1; }

/*  Some nice effects
    -----------------  */

.note {
    padding: 20px 14px;
    margin-bottom: 10px;
    background-image: -moz-linear-gradient(center top, #FFFF84 0%, #FFFF84 50%, #FFFF9E 100%);
    background-image: -webkit-gradient(linear, center top, center bottom, color-stop(0.21, #FFFF84), color-stop(0.61, #FFFF9E));

    -moz-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.235);
    -webkit-box-shadow: 0 3px 6px rgba(0, 0, 0, 0.235);
}

/*  Fancy input styles
    ------------------  */

input,
textarea,
progress,
select,
.note {
    -webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */
    -moz-box-sizing: border-box;    /* Firefox, other Gecko */
    box-sizing: border-box;         /* Opera/IE 8+ */
}

input[type=range] { height: 10px; } /* badly supported in FF */
input[type=url] { text-decoration: underline; }

input[type=text], input[type=password],
input[type=time], input[type=date], input[type=datetime],
input[type=datetime-local], input[type=email],
input[type=url], input[type=search], input[type=color],
input[type=tel], input[type=number], input[type=month], input[type=week],
select, textarea {
    margin: 1px 0;
}

input[type=text], input[type=password],
input[type=time], input[type=date], input[type=datetime],
input[type=datetime-local], input[type=email],
input[type=url], input[type=search], input[type=color],
input[type=tel], input[type=color], input[type=range], select{
    width: 140px;
}
input[type=number], input[type=month], input[type=week]{
    width: 80px;
    text-align: center;
}
input[type=text], input[type=password],
input[type=time], input[type=date], input[type=datetime],
input[type=datetime-local], input[type=email], input[type=number],
input[type=url], input[type=tel], input[type=search], input[type=color],
input[type=submit], input[type=button], input[type=reset], button,
textarea, select{
    padding: 4px 6px;
    border: 1px solid lightgray;
    border-radius: 4px;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
}

/* button specific styles */
button, input[type=button] { color: #000000; }
input[type=submit], button[type=submit] { color: #4169e1; }
input[type=reset], button[type=reset] { color: #b22222; }

input[type=submit], input[type=reset],
input[type=button], button {
    background-color: #FFFAFA;
    background: -moz-linear-gradient(90deg, #ECECEC, #F4F4F4) repeat scroll 0 0 transparent;
    background: -webkit-linear-gradient(90deg, #ECECEC, #F4F4F4) repeat scroll 0 0 transparent;
    cursor: pointer;
    font-weight: bold;
    font-size: 13px;
    font-family: arial;
}

input[type=submit]:active, input[type=button]:active, input[type=reset]:active, button:active{
    background-color: #EEE9E9;
    background: -moz-linear-gradient(90deg, #F4F4F4, #ECECEC) repeat scroll 0 0 transparent;
    background: -webkit-linear-gradient(90deg, #F4F4F4, #ECECEC) repeat scroll 0 0 transparent;
}

select{ background-color: #f9f9f9; }


/*      Default Layout: 992px.
        Gutters: 24px.
        Outer margins: 48px.
        Leftover space for scrollbars @1024px: 32px.
-------------------------------------------------------------------------------
cols    1     2      3      4      5      6      7      8      9      10
px      68    160    252    344    436    528    620    712    804    896    */
body{
	background-color: #FCFCFC;
    margin: auto;
    padding: 42px 0;
    -webkit-tap-highlight-color: rgb(255,255,0);
}
