{% load i18n staticfiles %}
<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="author" content="" />
    <meta name="keywords" content="" />
    <meta name="description" content="" />

    <title>{% block forumapp_title %}Welcome to ForumBR{% endblock %}</title>

    {% block forumapp_styles %}
    <link rel="stylesheet" type="text/css" href="{% static 'css/forum/normalize.css' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'css/forum/foundation.min.css' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'css/forum/styles.css' %}" />
    {% endblock %}

    {% block forumapp_js_top %}
    <script type="text/javascript" src="{% static 'js/forum/vendor/modernizr.js' %}"></script>
    {% endblock %}
</head>

<body>
    {% include 'forum/includes/menu.html' %}
    {% include 'forum/includes/system_messages.html' %}

    {% block forum_content %}{% endblock %}


    {% block forumapp_js_bottom %}
    <script type="text/javascript" src="{% static 'js/forum/vendor/jquery.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'js/forum/vendor/jquery.cookie.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'js/forum/foundation.min.js' %}"></script>
    {% endblock %}

    <script type="text/javascript">
    {% block forumapp_scripts %}
        $(document).foundation();
    {% endblock %}
    </script>

</body>

</html>
