{% for field in form.visible_fields %}
{% if field.errors %}
<div class="error">{{ field.errors }}</div>
{% endif %}

{% if no_label %}{% else %}
<div>{{ field.label_tag }}</div>
{% endif %}

{% if field.help_text %}
<div class="small quiet">{{ field.help_text }}</div>
{% endif %}
<div>{{ field }}</div>
{% endfor %}

{# renders hidden fields #}
{% for hidden in form.hidden_fields %}{{ hidden }}{% endfor %}