a { text-decoration: none; }
body .contain-to-grid{ margin-bottom: 1rem; }

td, th{ text-align: center !important; }
td:first-child, th:first-child{ text-align:left !important; }

table{ width:100%; border:1px solid lightgray; border-spacing:0px; }
table thead tr{ border-bottom: 1px solid lightgray; }

caption{ text-align:left; }

aside.profile { text-align: center; }
aside.profile ul { list-style: none; }
aside.profile .avatar { margin-bottom: 1rem; }
aside.profile .avatar img {
    border: 1px solid #50A1B3;
    margin-bottom: .5rem;
}

section.profile ul{ list-style: none; margin-left: 0 }

.paginate{ text-align:center; cursor:default; }
.paginate a:active{ cursor:pointer; }
.block { margin-bottom:10px; }

.user_profile aside .username{ text-align:center; }
.user_profile aside .avatar{ margin-bottom:5px; text-align:center; }
.user_profile aside .avatar img{ max-width:200px; max-height:200px; border:1px solid lightgray; }
.user_profile aside div.menu{ text-align:center; }

.user_profile section{ width:620px; display: inline-block; vertical-align:top; }

table.category .name { width: 30%; }
table.category .threads_counter { width: 15%; }
table.category .replies_counter { width: 15%; }
table.category .last_thread { width: 40%; }

table.forum .thread { width: 50%; }
table.forum .author { width: 20%; }
table.forum .replies_counter { width: 15%; }
table.forum .views_counter { width: 15%; }

header.forum > div{ display: inline-block; }
header.forum > div.breadcrumbs{ width:448px; text-align: left; }
header.forum > div.actions{ width:448px; text-align: right; }

ol.django_messages{ list-style: none; margin-left: 0; }
ol.django_messages .error{
    color:#EE3B3B;
    border: 1px solid #F08080;
    background-color: #FFE4E1;
}
ol.django_messages .warning{ background-color: #FBA03A; }
ol.django_messages .close{
    font-weight: bold;
    opacity: .8;
}

.user_profile .edit_profile .clear{ clear:both; }
.user_profile .messages tr .messages_subject{ width: 50%;  text-align:left; }
.user_profile .messages tr .messages_author{ width: 25%; text-align: center; }
.user_profile .messages tr .messages_date{ width: 25%; text-align: center; }

.user_profile .profile_list { list-style: none; }
.user_profile .profile_list li{ margin-left:10px; }
.user_profile .profile_list li label{ text-align:left; width:200px; }
.user_profile .profile_list .signature { padding: 10px; }
.user_profile .profile_list .signature > div{ background-color: white; border: 1px solid #d3d3d3; padding: 10px; }

.user_profile a.send_pvt{ font-weight:bold; }

.reply{ margin-bottom: 1rem; border:1px solid #abc; }
.reply header { border-bottom:1px solid #abc; }
.reply header, .reply aside, .reply section, .reply section div.content{ padding:.4rem; }
.reply section{ vertical-align:top; }
.reply .body { border: 1px solid #d3d3d3; border-top:none; }

#forum .thread_actions{ text-align:right; }

.thread .image img{ max-width:100%; }
.thread .attach span{ cursor:default; }
.thread .attach {
    border: 1px solid #d3d3d3;
    margin: 5px 0px 10px 0px;
    padding: 4px;
    text-align: right;
}

.error ul.errorlist {
    color:#EE3B3B;
    list-style:none;
    padding:.5rem;
    margin: .5rem 0;
    margin-left: 0;
    border: 2px solid lightcoral;
    background-color: mistyrose;
}
.errorlist li{ margin-left:10px; }