{% extends "forum/base.html" %}
{% load i18n %}

{% block forum_content %}
    <div class="row">
        <h1>Forum Registration</h1>

        <form method="post">{% csrf_token %}
            <input type="submit" value="{% trans 'Register' %}"/>
        </form>
    </div>
{% endblock %}