{% extends "forum/base.html" %}
{% load i18n staticfiles %}

{% block forumapp_styles %}{{ block.super }}
    <link rel="stylesheet" type="text/css"
        href="{% static 'js/forum/markitup/skins/simple/style.css' %}" />

    <link rel="stylesheet" type="text/css" href='{% static editor_style %}' />
{% endblock %}

{% block forumapp_js_bottom %}
    {{ block.super }}
    <script type="text/javascript"
            src="{% static 'js/forum/markitup/jquery.markitup.js' %}"></script>
    <script type="text/javascript" src="{% static editor_set %}"></script>

    <script type="text/javascript" >
        $(document).ready(function() {
            $('textarea').markItUp(mySettings);
        });
    </script>
{% endblock %}

{% block forum_content %}
{% include "forum/includes/breadcrumbs.html" %}

<div class="row">
    <p>
        <strong>{% trans "Reply to" %} <a href="{{ thread.get_absolute_url }}">{{ thread }}</a></strong>
    </p>
    <form method="post">{% csrf_token %}
        {% include "forum/form.html" with no_label=1 %}
        <input class="tiny button" type="submit" name="send" value='{% trans "Send" %}' />
        <input class="tiny button" type="submit" name="preview" value='{% trans "Preview" %}' />
    </form>
</div>
{% endblock %}
