{% extends "forum/base.html" %}
{% load i18n %}

{% block forum_content %}
    <div class="row">
        <aside class="column small-12 medium-4 large-3 profile">
            <h3><a href='{{ profile.get_absolute_url }}'>{{ profile }}</a></h3>

            <div class="avatar">
                <img alt='{% trans "avatar image" %}'
                        {% if profile and profile.avatar %}
                     src="{{ profile.get_avatar_url }}"
                     title='{% trans "Avatar image for" %} {{ forum_user }}'
                        {% else %}
                     src="{{ STATIC_URL }}img/forum/avatar/dull_face.png"
                     title='{% trans "Default image" %}'
                        {% endif %} />
                {% if is_self %}
                    <div class="menu">
                        <a id="edit_avatar" title='{% trans "Change your avatar image" %}'
                           href="{% url 'forum:edit_profile' %}">{% trans "Edit profile" %}</a>
                    </div>
                {% endif %}
            </div>
            {% block profile_aside %}{% endblock %}
        </aside>

        <section class="profile panel column small-12 medium-8 large-9">
            {% block profile_content %}
                <ul>
                    <li>
                        <b>{% trans "Registered since" %}</b>
                        {{ profile.creation_time|date }}
                    </li>
                    <li>
                        <span title="You sure?"><b>{% trans "Of gender" %}</b> {{ profile.get_gender_display }}</span>
                    </li>
                    <li>
                        <span><b>{% trans "With reputation of" %}</b> {{ profile.reputation }}</span>
                    </li>
                    <li>
                        <span><b>{% trans "Has" %}</b> {{ profile.threads_counter }} <b>
                            {% trans "thread" %}{{ profile.threads_counter|pluralize }}</b></span>
                    </li>
                    <li>
                        <span><b>{% trans "And" %}</b> {{ profile.replies_counter }} <b>
                            {% trans "repl" %}{{ profile.replies_counter|pluralize:"y,ies" }}</b></span>
                    </li>
                    {% if profile.message %}
                        <li class="signature">
                            {% if profile.message %}
                                <div>
                                    {{ profile.html|safe }}
                                </div>
                            {% endif %}
                        </li>
                    {% endif %}
                </ul>
                {% if not is_self %}
                    <a class="button small" title='{% trans "send private message" %}'
                       href='{% url 'forum:send_message' profile.nickname %}'>Send message</a>
                {% endif %}
            {% endblock %}
        </section>
    </div>
{% endblock %}