{% extends "forum/profile.html" %}
{% load i18n %}

{% block profile_content %}
<div id="send_pvt">
    <h3>New message for <a href='{{ recipient.get_absolute_url }}'>{{ recipient }}</a></h3>
    <form method="post">{% csrf_token %}
        {% include "forum/form.html" %}
        <input class="button small" type="submit" value='{% trans "Send" %}' />
    </form>
</div>
{% endblock %}
