{% load i18n %}
<div class="contain-to-grid">
    <nav class="top-bar" data-topbar>
        <ul class="title-area">
            <li class="name"><h1><a href="{% url 'forum:index' %}">Forum</a></h1></li>
            <li class="toggle-topbar menu-icon"><a href="#">Menu</a></li>
        </ul>
        <section class="top-bar-section"> <!-- Right Nav Section -->
            <ul class="left">
                {% if user.is_authenticated %}
                    <li>
                        <a href='{% url 'forum:profile' %}'>{{ user.forum_profile }}</a>
                    </li>
                    <li>
                        <a href='{% url 'forum:messages' %}'>{% trans "Messages" %}</a>
                    </li>
                    <li>
                        <a href="/accounts/logout/">Logout</a>
                    </li>
                {% else %}
                    <li>
                        <a href="/accounts/login/">Login</a>
                    </li>
                {% endif %}
            </ul>
        </section>
    </nav>
</div>