{% load i18n %}
<header class="forum row">
    <ul class="breadcrumbs">
        <li><a href="{{ category.get_absolute_url }}">{{ category }}</a></li>

        {% for parent_forum in forum.parent_tree %}
        <li><a href="{{ parent_forum.get_absolute_url }}">{{ parent_forum }}</a></li>
        {% endfor %}

        <li><a href="{{ forum.get_absolute_url }}">{{ forum }}</a></li>
    </ul>
</header>