{% extends "forum/profile.html" %}
{% load i18n %}

{% block profile_content %}
<div class="messages">
    <h2>{{ pvt.title }}</h2>
    <div class="clear small quiet">{{ pvt.created }}</div>
    <div class="content">
        <p>
            {{ pvt.message }}
        </p>
    </div>
    <div>
        <a href='{% url 'forum:send_message' pvt.author %}'>{% trans "Reply" %}</a>
    </div>
</div>
{% endblock %}