{% if messages %}
    <div class="row">
        <ol class="django_messages">
            {% for message in messages %}
                <li>
                    <div data-alert class="alert-box radius {{ message.tags }}">
                        {{ message }}
                        <a href="#" class="close">&times;</a>
                    </div>
                </li>
            {% endfor %}
        </ol>
    </div>
{% endif %}